==> lincvs_1.4.0.orig.tar.gz: lincvs-1.4.0/src/cvstoolbar.h <==
/****************************************************************************
 **
 ** $Id: cvstoolbar.h,v 1.21 2004/10/06 00:07:54 frank Exp $
 **
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
 **    Frank Hemer <frank@hemer.org>
 **    Wim Delvaux <wim.delvaux@chello.be>
 **    Jose Hernandez <joseh@tesco.net>
 **    Helmut Koll <HelmutKoll@web.de>
 **    Tom Mishima <tmishima@mail.at-m.or.jp>
 **    Joerg Preiss <auba@auba.de>
 **    Sven Trogisch <trogisch@iapp.de>
 **
 **
 **----------------------------------------------------------------------------
 **
 **----------------------------------------------------------------------------
 **
 ** LinCVS is available under two different licenses:
 **
 ** If LinCVS is linked against the GPLed version of Qt 
 ** LinCVS is released under the terms of GPL also.
 **
 ** If LinCVS is linked against a nonGPLed version of Qt 
 ** LinCVS is released under the terms of the 
 ** LinCVS License for non-Unix platforms (LLNU)
 **
 **
 ** LinCVS License for non-Unix platforms (LLNU):
 **
 ** Redistribution and use in binary form, without modification, 
 ** are permitted provided that the following conditions are met:
 **
 ** 1. Redistributions in binary form must reproduce the above copyright
 **    notice, this list of conditions and the following disclaimer in the
 **    documentation and/or other materials provided with the distribution.
 ** 2. It is not permitted to distribute the binary package under a name
 **    different than LinCVS.
 ** 3. The name of the authors may not be used to endorse or promote
 **    products derived from this software without specific prior written
 **    permission.
 ** 4. The source code is the creative property of the authors.
 **    Extensions and development under the terms of the Gnu Public License
 **    are limited to the Unix platform. Any distribution or compilation of 
 **    the source code against libraries licensed other than gpl requires 
 **    the written permission of the authors.
 **
 **
 ** THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR 
 ** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 ** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 ** ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
 ** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 ** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
 ** GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 ** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 ** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
 ** NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
 ** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **
 **
 **
 ** LinCVS License for Unix platforms:
 **
 ** This program is free software; you can redistribute it and/or modify 
 ** it under the terms of the GNU General Public License as published by 
 ** the Free Software Foundation; either version 2 of the License, or 
 ** (at your  option) any later version.  This program is distributed in 
 ** the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 ** even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 ** PARTICULAR PURPOSE.
 **
 ** See the GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software Foundation,
 ** Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 **
 *****************************************************************************/


#ifndef CVSTOOLBAR_H_20010626		// prevent multiple includes
#define CVSTOOLBAR_H_20010626

#include "config.h"

#include <qmainwindow.h>
#include <qtoolbutton.h>
#include <qtoolbar.h>


class cvsToolbar : public QToolBar
{
   Q_OBJECT

 signals:

   void autoUpdateStateChanged();

 public:
   cvsToolbar(QMainWindow *parent );
   ~cvsToolbar();

   typedef enum {      // the objects are defined here
      wBench,           // workbench
      cvsFile,          // cvs file tab
      nonCvsFile,       // non cvs file tab
      cvsIgnoreFile,    // cvs ignore tab
      tabFileList,      // file tabs
      status            // status field
   }T_wtText;
   
   QToolButton          *m_pStopAction;
   void setEnabled(bool);
   void autoUpdateChanged();

   QIconSet whatsThisIconSet() const { return m_whatsThisIconSet; }

   
 public slots:
   
   void addWhatsThisText( void *ptr,  T_wtText textType );
    
 private:
   QToolButton          *tb_exit;
   QToolButton          *tb_addWb;
   QToolButton          *tb_info;
   QToolButton          *tb_imp;
   QToolButton          *tb_co;
   QToolButton          *tb_upd;
   QToolButton          *tb_autoupd;
   QToolButton          *tb_cvsUpd;
   QToolButton          *tb_cvsMerge;
   QToolButton          *tb_com;
   QToolButton          *tb_annotate;
   QToolButton          *tb_annotateGrepLine;
   QToolButton          *tb_annotateGrepLines;
   QToolButton          *tb_watchAdd;
   QToolButton          *tb_watchRemove;
   QToolButton          *tb_watchOn;
   QToolButton          *tb_watchOff;

   //whatsthis iconset --> needed for our own whatsthis buttons inside of the dlgs
   QIconSet m_whatsThisIconSet;

   typedef enum {      // only toolbuttons defined here 
      add2Wb,           // workbench
      stopAction,       // stop Button
      exit,
      info,
      import,
      co,               // checkout Button
      upd,              // update Button
      autoupd,          // auto update module Button
      cvsupd,           // cvs update
      cvscom,           // cvs commit
      cvsmerge          // cvs merge
   } T_wtTextInt;       // whatsThisText internal functions 



 private slots:

   void addWhatsThisTextInt (QToolButton *tb, T_wtTextInt textType );
   void toggle_autoupdate();

};


#endif // CVSTOOLBAR_H_20010626

==> lincvs_1.4.4.orig.tar.gz: lincvs-1.4.4/src/cvstoolbar.h <==
/****************************************************************************
 **
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
 **    Falk Brettschneider <gigafalk@yahoo.com>
 **    Frank Hemer <frank@hemer.org>
 **    Wim Delvaux <wim.delvaux@chello.be>
 **    Jose Hernandez <joseh@tesco.net>
 **    Helmut Koll <HelmutKoll@web.de>
 **    Tom Mishima <tmishima@mail.at-m.or.jp>
 **    Joerg Preiss <auba@auba.de>
 **    Sven Trogisch <trogisch@iapp.de>
 **
 **
 **----------------------------------------------------------------------------
 **
 **----------------------------------------------------------------------------
 **
 ** LinCVS is available under two different licenses:
 **
 ** If LinCVS is linked against the GPLed version of Qt 
 ** LinCVS is released under the terms of GPL also.
 **
 ** If LinCVS is linked against a nonGPLed version of Qt 
 ** LinCVS is released under the terms of the 
 ** LinCVS License for non-Unix platforms (LLNU)
 **
 **
 ** LinCVS License for non-Unix platforms (LLNU):
 **
 ** Redistribution and use in binary form, without modification, 
 ** are permitted provided that the following conditions are met:
 **
 ** 1. Redistributions in binary form must reproduce the above copyright
 **    notice, this list of conditions and the following disclaimer in the
 **    documentation and/or other materials provided with the distribution.
 ** 2. It is not permitted to distribute the binary package under a name
 **    different than LinCVS.
 ** 3. The name of the authors may not be used to endorse or promote
 **    products derived from this software without specific prior written
 **    permission.
 ** 4. The source code is the creative property of the authors.
 **    Extensions and development under the terms of the Gnu Public License
 **    are limited to the Unix platform. Any distribution or compilation of 
 **    the source code against libraries licensed other than gpl requires 
 **    the written permission of the authors.
 **
 **
 ** THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR 
 ** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 ** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 ** ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
 ** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 ** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
 ** GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 ** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 ** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
 ** NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
 ** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **
 **
 **
 ** LinCVS License for Unix platforms:
 **
 ** This program is free software; you can redistribute it and/or modify 
 ** it under the terms of the GNU General Public License as published by 
 ** the Free Software Foundation; either version 2 of the License, or 
 ** (at your  option) any later version.  This program is distributed in 
 ** the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 ** even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 ** PARTICULAR PURPOSE.
 **
 ** See the GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software Foundation,
 ** Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 **
 *****************************************************************************/


#ifndef CVSTOOLBAR_H_20010626		// prevent multiple includes
#define CVSTOOLBAR_H_20010626

#include "config.h"

#include <qmainwindow.h>
#include <qtoolbutton.h>
#include <qtoolbar.h>


class cvsToolbar : public QToolBar
{
   Q_OBJECT

 signals:

   void autoUpdateStateChanged();

 public:
   cvsToolbar(QMainWindow *parent );
   ~cvsToolbar();

   typedef enum {      // the objects are defined here
      wBench,           // workbench
      cvsFile,          // cvs file tab
      nonCvsFile,       // non cvs file tab
      cvsIgnoreFile,    // cvs ignore tab
      tabFileList,      // file tabs
      status            // status field
   }T_wtText;
   
   QToolButton          *m_pStopAction;
   void setEnabled(bool);
   void autoUpdateChanged();

   QIconSet whatsThisIconSet() const { return m_whatsThisIconSet; }

   
 public slots:
   
   void addWhatsThisText( void *ptr,  T_wtText textType );
    
 private:
   QToolButton          *tb_exit;
   QToolButton          *tb_addWb;
   QToolButton          *tb_info;
   QToolButton          *tb_imp;
   QToolButton          *tb_co;
   QToolButton          *tb_upd;
   QToolButton          *tb_autoupd;
   QToolButton          *tb_cvsUpd;
   QToolButton          *tb_cvsMerge;
   QToolButton          *tb_com;
   QToolButton          *tb_annotate;
   QToolButton          *tb_annotateGrepLine;
   QToolButton          *tb_annotateGrepLines;
   QToolButton          *tb_watchAdd;
   QToolButton          *tb_watchRemove;
   QToolButton          *tb_watchOn;
   QToolButton          *tb_watchOff;

   //whatsthis iconset --> needed for our own whatsthis buttons inside of the dlgs
   QIconSet m_whatsThisIconSet;

   typedef enum {      // only toolbuttons defined here 
      add2Wb,           // workbench
      stopAction,       // stop Button
      exit,
      info,
      import,
      co,               // checkout Button
      upd,              // update Button
      autoupd,          // auto update module Button
      cvsupd,           // cvs update
      cvscom,           // cvs commit
      cvsmerge,         // cvs merge
      annotate,
      annotateGrepLine,
      annotateGrepLines,
      watchAdd,
      watchRemove,
      watchOn,
      watchOff
   } T_wtTextInt;       // whatsThisText internal functions 



 private slots:

   void addWhatsThisTextInt (QToolButton *tb, T_wtTextInt textType );
   void toggle_autoupdate();

};


#endif // CVSTOOLBAR_H_20010626
